package com.ff.game.mapper;

import java.util.List;
import com.ff.game.domain.GameFreeRecord;

/**
 * 免费赠送游戏记录Mapper接口
 * 
 * @author shi
 * @date 2025-02-10
 */
public interface GameFreeRecordMapper 
{
    /**
     * 查询免费赠送游戏记录
     * 
     * @param id 免费赠送游戏记录主键
     * @return 免费赠送游戏记录
     */
     GameFreeRecord selectGameFreeRecordById(Long id);

    /**
     * 查询免费赠送游戏记录列表
     * 
     * @param gameFreeRecord 免费赠送游戏记录
     * @return 免费赠送游戏记录集合
     */
     List<GameFreeRecord> selectGameFreeRecordList(GameFreeRecord gameFreeRecord);

    /**
     * 新增免费赠送游戏记录
     * 
     * @param gameFreeRecord 免费赠送游戏记录
     * @return 结果
     */
     int insertGameFreeRecord(GameFreeRecord gameFreeRecord);

    /**
     * 修改免费赠送游戏记录
     * 
     * @param gameFreeRecord 免费赠送游戏记录
     * @return 结果
     */
     int updateGameFreeRecord(GameFreeRecord gameFreeRecord);

    /**
     * 删除免费赠送游戏记录
     * 
     * @param id 免费赠送游戏记录主键
     * @return 结果
     */
     int deleteGameFreeRecordById(Long id);

    /**
     * 批量删除免费赠送游戏记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteGameFreeRecordByIds(Long[] ids);
}
